@@ -228,16 +228,16 @@ static XPoint trapazoidUnit[5] =
 #endif /* defined(SYSV) || defined(SVR4) */
 
 static int
-usleep(unsigned long usec)
+usleep(unsigned int usec)
 {
 #if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
 #if defined(HAVE_NANOSLEEP)
 	{
 		struct timespec rqt;
 
-		rqt.tv_nsec = 1000 * (usec % (unsigned long) 1000000);
-		rqt.tv_sec = usec / (unsigned long) 1000000;
-		return nanosleep(&rqt, NULL);
+		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
+		rqt.tv_sec = usec / (unsigned int) 1000000;
+		return nanosleep(&rqt, (struct timespec *) NULL);
 	}
 #else
 	(void) poll((void *) 0, (int) 0, usec / 1000);	/* ms resolution */
@@ -262,8 +262,8 @@ usleep(unsigned long usec)
 
 #endif
 
-	time_out.tv_usec = usec % (unsigned long) 1000000;
-	time_out.tv_sec = usec / (unsigned long) 1000000;
+	time_out.tv_usec = usec % (unsigned int) 1000000;
+	time_out.tv_sec = usec / (unsigned int) 1000000;
 	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
 #endif
 #endif
@@ -272,7 +272,7 @@ usleep(unsigned long usec)
 #endif
 
 static void
-Sleep(unsigned long cMilliseconds)
+Sleep(unsigned int cMilliseconds)
 {
 	(void) usleep(cMilliseconds * 1000);
 }
@@ -881,7 +881,7 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition, int toStack, int toPos
 		currentPosition = nextPosition;
 		DrawTile(w, currentStack, currentPosition, False, FALSE);
 		XFlush(XtDisplay(w));
-		Sleep((unsigned long) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
+		Sleep((unsigned int) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
 	}
 	while (currentStack != toStack) {
 		DrawTile(w, currentStack, currentPosition, True, FALSE);
@@ -895,7 +895,7 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition, int toStack, int toPos
 		currentStack = nextStack;
 		DrawTile(w, currentStack, currentPosition, False, FALSE);
 		XFlush(XtDisplay(w));
-		Sleep((unsigned long) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
+		Sleep((unsigned int) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
 	}
 	while (currentPosition < toPosition) {
 		DrawTile(w, currentStack, currentPosition, True, FALSE);
@@ -908,7 +908,7 @@ SlideTile(PanexWidget w, int fromStack, int fromPosition, int toStack, int toPos
 		currentPosition = nextPosition;
 		DrawTile(w, currentStack, currentPosition, False, FALSE);
 		XFlush(XtDisplay(w));
-		Sleep((unsigned long) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
+		Sleep((unsigned int) w->panex.delay / (w->panex.tiles + MAXSTACKS - 1));
 	}
 }
 
@@ -1025,6 +1025,7 @@ DrawPyramid(PanexWidget w, int color, int i, int j, int size, int offset)
 {
 	XPoint      trapazoidList[5];
 	int         k;
+	GC          pyramidGC;
 
 	for (k = 0; k <= 4; k++) {
 		if (ABS(trapazoidUnit[k].x) == 3)
@@ -1044,19 +1045,28 @@ DrawPyramid(PanexWidget w, int color, int i, int j, int size, int offset)
 	trapazoidList[0].y = j * w->panex.pos.y + w->panex.delta.y +
 		w->panex.puzzleOffset.y + offset + 2;
 	if (w->panex.mono || w->panex.depth < 2) {
+		pyramidGC = (offset) ? w->panex.tileGC : w->panex.borderGC;
+	} else {
+		if ((w->panex.pyramidColor[color] == w->panex.borderColor) && offset)
+			pyramidGC = w->panex.tileGC;
+		else if ((w->panex.pyramidColor[color] == w->panex.tileColor) && !offset)
+			pyramidGC = w->panex.borderGC;
+		else
+			pyramidGC = w->panex.pyramidGC[color];
+
+	}
+	XFillPolygon(XtDisplay(w), XtWindow(w), pyramidGC,
+		     trapazoidList, 4, Convex, CoordModePrevious);
+	if (w->panex.mono || w->panex.depth < 2) {
+
 		char        buf[2];
 
-		XFillPolygon(XtDisplay(w), XtWindow(w),
-			     (offset) ? w->panex.tileGC : w->panex.inverseGC,
-			     trapazoidList, 4, Convex, CoordModePrevious);
 		(void) sprintf(buf, "%c", w->panex.pyramidName[color][0]);
 		XDrawString(XtDisplay(w), XtWindow(w),
-			    (offset) ? w->panex.inverseGC : w->panex.tileGC,
+			    (offset) ? w->panex.borderGC : w->panex.tileGC,
 			    k - w->panex.letterOffset.x, trapazoidList[0].y +
 		  w->panex.tileSize.y / 2 + w->panex.letterOffset.y, buf, 1);
-	} else
-		XFillPolygon(XtDisplay(w), XtWindow(w), w->panex.pyramidGC[color],
-			     trapazoidList, 4, Convex, CoordModePrevious);
+	}
 }
 
 #if 0
